Learn R Programming

AnxietySleep (version 0.0.1)

anxiety: Data from the anxiety and confinement study.

Description

[Stable]

This dataset contains the variables used in the anxiety and confinement study carried out by Alvarado-Aravena et al. 2022.

Usage

anxiety

Arguments

Format

A data frame with 617 rows y 7 variables:

  • id: Factor. An identification code for each subject.

  • sex: Factor w/ 2 levels "Female", "Male". Sex of participants.

  • zone: Factor w/ 2 levels "CZ", "PZ". Zone in which the subject were by the time he was answering the questionnaire, either CZ (Confinement Zone) or PZ (Partial confinement Zone).

  • beck_global: Integer. Global score of Beck Anxiety Inventory.

  • pits_global: Integer. Global score of Pittsburgh Sleep Quality Index.

  • age: Integer. Age of the subjects in years.

  • cat_age: Factor w/ 4 levels "18-25", "26-40", "41-50", ">50". Age of the subjects in years.

Examples

Run this code
# Mean age grouped by sex and zone using `data.table` syntax
anxiety[,  # No filtering (i)
        list(mean_age = mean(age)), # Action to do (j)
        list(sex, zone)] # Grouping vars (by)

# Mean PSQI score grouped by sex and zone, for those with
# an age greater than 18 AND a Beck score greater than 10.
anxiety[age > 18 & beck_global > 10,
        list(mean_psqi = mean(pits_global)),
        list(sex, zone)]

Run the code above in your browser using DataLab